=============
Configuration
=============

HELPCENTER_ARTICLE_CREATE_FORM (=None)
  Determines which form to use for creating new articles. The default
  is to use an autogenerated ``ModelForm``.

HELPCENTER_ARTICLE_UPDATE_FORM (=None)
  Determines which form to use for editing articles. The default is to
  use an autogenerated ``ModelForm``.

HELPCENTER_ARTICLES_PER_PAGE (=10)
  The number of articles to display per page. This affects the detail
  view for categories.

HELPCENTER_CATEGORY_CREATE_FORM (=None)
  Determines which form to use for creating new categories. The default
  is to use an autogenerated ``ModelForm``.

HELPCENTER_CATEGORY_UPDATE_FORM (=None)
  Determines which form to use for editing categories. The default is
  to use an autogenerated ``ModelForm``.

HELPCENTER_EXPANDED_ARTICLE_LIST (=False)
  By default, the only articles listed in a category's detail view are
  the ones that are direct children of that category. If this setting
  is ``True``, all articles that are children of that category *or its
  descendants* will be shown.

  For example, if there are two categories ``parent`` and ``child``, each
  with an article in them, then if this setting is ``True``, the article
  listing for ``parent`` would include the articles from both categories.
